==> UniEvent-HTTP-1.2.2.tar.gz: UniEvent-HTTP-1.2.2/clib/tests/client/live.cc <==
#include "../lib/test.h"
#include <openssl/ssl.h>

#define TEST(name) TEST_CASE("client-live: " name, "[client-live]" VSSL)

#define panda_log_module panda::unievent::http::panda_log_module

TEST("get real sites") {
    std::vector<string> sites = {
        "http://google.com",
        "http://youtube.com",
        "http://facebook.com",
        "http://wikipedia.org",
        "http://yandex.ru",
        "http://ya.ru",
        "http://example.com"
    };

    AsyncTest test(5000, sites.size());

    for (auto site : sites) {
        panda_log_debug("request to: " << site);
        RequestSP req = Request::Builder()
            .uri(site)
            .response_callback([&](auto&, auto& res, auto& err) {
                panda_log_debug("GOT response " << res << ", " << res->body.length() << " bytes, err=" << err);
                test.happens();
                CHECK_FALSE(err);
                CHECK(res->code == 200);
            })
            .build();
        http_request(req, test.loop);
    }

    test.run();
}

TEST("validate host name") {
    AsyncTest test(5000, 1);
    RequestSP req = Request::Builder()
        .uri("https://a.b.c.dev.crazypanda.ru")
        .response_callback([&](auto&, auto& res, auto& err) {
            panda_log_debug("GOT response " << res << ", " << res->body.length() << " bytes, err=" << err);
            test.happens();
            CHECK(err);
        })
        .ssl_check_cert(true)
        .build();
    http_request(req, test.loop);
    test.run();
}

==> UniEvent-HTTP-1.2.3.tar.gz: UniEvent-HTTP-1.2.3/clib/tests/client/live.cc <==
#include "../lib/test.h"
#include <openssl/ssl.h>

#define TEST(name) TEST_CASE("client-live: " name, "[client-live]" VSSL)

#define panda_log_module panda::unievent::http::panda_log_module

TEST("get real sites") {
    std::vector<string> sites = {
        "http://google.com",
        "http://youtube.com",
        "http://facebook.com",
        "http://wikipedia.org",
        "http://yandex.ru",
        "http://ya.ru",
        "http://example.com"
    };

    AsyncTest test(5000, sites.size());

    for (auto site : sites) {
        panda_log_debug("request to: " << site);
        RequestSP req = Request::Builder()
            .uri(site)
            .response_callback([&](auto&, auto& res, auto& err) {
                panda_log_debug("GOT response " << res << ", " << res->body.length() << " bytes, err=" << err);
                test.happens();
                CHECK_FALSE(err);
                CHECK(res->code == 200);
            })
            .build();
        http_request(req, test.loop);
    }

    test.run();
}

TEST("validate host name") {
    AsyncTest test(5000, 1);
    RequestSP req = Request::Builder()
        .uri("https://a.b.c.dev.crazypanda.ru")
        .response_callback([&](auto&, auto& res, auto& err) {
            panda_log_debug("GOT response " << res << ", " << res->body.length() << " bytes, err=" << err);
            test.happens();
            CHECK(err);
        })
        .ssl_check_cert(true)
        .build();
    http_request(req, test.loop);
    test.run();
}

TEST("google.com cert from system") {
    AsyncTest test(5000);

    TClientSP client = new TClient(test.loop);

    auto req = Request::Builder().method(Request::Method::Get)
            .uri("https://google.com")
            .ssl_check_cert(true)
            .build();
    auto res = client->get_response(req);

    CHECK(res->code == 200);
    CHECK(res->http_version == 11);
}
